import { Request, Response } from 'express';
import { prisma } from '../../../lib/prisma';
import { Prisma } from '@prisma/client';

export async function searchArticles(req: Request, res: Response) {
  try {
    const { q, page = 1, limit = 9 } = req.query;
    const skip = ((Number(page) || 1) - 1) * (Number(limit) || 9);

    // Определение where с явной обработкой q
    const where : Prisma.ArticleWhereInput =
        typeof q === 'string' && q.trim()
            ? {
              OR: [
                { title: { contains: q, mode: 'insensitive' } },
                { excerpt: { contains: q, mode: 'insensitive' } },
                { content: { contains: q, mode: 'insensitive' } },
              ],
            }
            : {};

    // Выполнение запросов
    const [articles, total] = await Promise.all([
      prisma.article.findMany({
        where,
        include: {
          author: {
            select: {
              id: true,
              displayName: true,
              avatarUrl: true,
              email: true,
            },
          },
        },
        skip,
        take: Number(limit) || 9,
        orderBy: { publishedAt: 'desc' },
      }),
      prisma.article.count({ where }),
    ]);

    // Формирование ответа
    res.json({
      articles,
      totalPages: Math.ceil(total / (Number(limit) || 9)),
      currentPage: Number(page) || 1,
    });
  } catch (error) {
    console.error('Error during article search:', error);
    res.status(500).json({ error: 'Server error' });
  }
}
